# Cheermeup
![](demo.gif)
Command line program that plays random animal videos to cheer you up !

Created by [u/andohuman](https://www.reddit.com/user/andohuman) | [@andohuman](https://twitter.com/andohuman)
## 1. Getting started 
This script works by scraping videos from a couple of popular animal subreddits.

You need to have python3 installed on your system.
## 2. Installation
1. Clone this repository

```git clone https://github.com/andohuman/cheermeup.git```

If you're on windows you can download the zip from [here](https://github.com/andohuman/cheermeup/archive/master.zip) and extract the archive.

2. cd into the folder and install the package by executing

```cd cheermeup```

```pip3 install . --user```

from your terminal.

Note :- If you're on linux you might have to add ```/home/{USERNAME}/.local/bin/``` to your ```$PATH```.

3. Run the script by executing ```cheermeup``` and enjoy.

Note:- When you run the problem for the first time (of the day) it'll take a couple of minutes to fetch the links and cache them. So, give it a couple of seconds.

If you find any bugs or want to make some improvements feel free to issue a pull request.
